#[non_exhaustive]pub enum PdfError {
Parse,
Encrypted,
PageOutOfRange {
index: usize,
count: usize,
},
}Expand description
An error loading or rasterizing a PDF document.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Parse
The bytes could not be parsed as a PDF document.
Encrypted
The document is encrypted / password-protected, which is not supported.
PageOutOfRange
The requested page index is out of range for the document.